==> website-php-v.1.0.92.zip: lang/en/wsp-admin/theme/configure-css.inc.php <==
<?php
	define("NO_PICTURE", "No picture");
	define("CURRENT_PICTURE", "Current picture");
	define("EDT_BACKGROUND_BODY", "Background Body color");
	define("EDT_BCK_BODY_PIC", "Background Body picture");
	define("EDT_BCK_BODY_PIC_REPEAT", "Background Body picture repeat");
	define("EDT_BCK_BODY_PIC_POSITION", "Background Body picture position");
	define("EDT_COLOR_BODY", "Text body color");
	define("EDT_LINK_COLOR", "Link color");
	define("EDT_LINK_HOVER_COLOR", "Hover link color");
	define("CMB_BCK_PICTURE_1", "Box background picture %s");
	define("EDT_BCK_1_HEADER", "Header background color %s");
	define("EDT_COLOR_1_HEADER", "Header text color %s");
	define("EDT_COLOR_1_HEADER_LINK", "Header link color %s");
	define("EDT_COLOR_1_HEADER_LINK_HOVER", "Header hover link color %s");
	define("EDT_BCK_1", "Background color %s");
	define("EDT_COLOR_1", "Text color %s");
	define("EDT_COLOR_1_LINK", "Link color %s");
	define("EDT_COLOR_1_LINK_HOVER", "Hover link color %s");
	define("EDT_BCK_BORDER_TABLE_1", "Border color %s");
	define("EDT_COLOR_SHADOW", "Box shadow color %s");
	define("EDT_STYLE_GRADIENT", "Activate Box gradient %s");
	define("EDT_STYLE_FONT", "Font style");
	define("EDT_FONT_SIZE", "Font size");
	define("EDT_STYLE_FONT_SERIF", "Serif");
	define("EDT_STYLE_JQUERY", "jQuery style");
	define("CMB_NB_PREDEFINE_STYLE", "Nb predefined style");
	define("CMB_CURRENT_PREDEFINE_STYLE", "Current predefined style");
	define("VIEW_DIALOGBOX", "Click here to view a DialogBox");
	define("DIALOGBOX_TITLE", "DialogBox title");
	define("DIALOGBOX_CONTENT", "DialogBox content");
	define("TEXT_ON_BODY", "Sample text on the page");
	define("LINK_ON_BODY", "Sample link on the page");
	define("BODY_TEXT_LINK_NOTE", "See bottom of page");
	define("WARNING_CHANGE_PLEASE_SAVE", "Warning, please save the form before change this field.");
?>

==> website-php-v.1.1.5.zip: lang/en/wsp-admin/theme/configure-css.inc.php <==
<?php
	define("NO_PICTURE", "No picture");
	define("CURRENT_PICTURE", "Current picture");
	define("EDT_BACKGROUND_BODY", "Background Body color");
	define("EDT_BCK_BODY_PIC", "Background Body picture");
	define("EDT_BCK_BODY_PIC_REPEAT", "Background Body picture repeat");
	define("EDT_BCK_BODY_PIC_POSITION", "Background Body picture position");
	define("EDT_COLOR_BODY", "Text body color");
	define("EDT_LINK_COLOR", "Link color");
	define("EDT_LINK_HOVER_COLOR", "Hover link color");
	define("CMB_BCK_PICTURE_1", "Box background picture %s");
	define("EDT_BCK_1_HEADER", "Header background color %s");
	define("EDT_COLOR_1_HEADER", "Header text color %s");
	define("EDT_COLOR_1_HEADER_LINK", "Header link color %s");
	define("EDT_COLOR_1_HEADER_LINK_HOVER", "Header hover link color %s");
	define("EDT_BCK_1", "Background color %s");
	define("EDT_COLOR_1", "Text color %s");
	define("EDT_COLOR_1_LINK", "Link color %s");
	define("EDT_COLOR_1_LINK_HOVER", "Hover link color %s");
	define("EDT_BCK_BORDER_TABLE_1", "Border color %s");
	define("EDT_COLOR_SHADOW", "Box shadow color %s");
	define("EDT_STYLE_GRADIENT", "Activate Box gradient %s");
	define("EDT_STYLE_FONT", "Font style");
	define("EDT_FONT_SIZE", "Font size");
	define("EDT_STYLE_FONT_SERIF", "Serif");
	define("EDT_STYLE_JQUERY", "jQuery style");
	define("CMB_NB_PREDEFINE_STYLE", "Nb predefined style");
	define("CMB_CURRENT_PREDEFINE_STYLE", "Current predefined style");
	define("VIEW_DIALOGBOX", "Click here to view a DialogBox");
	define("DIALOGBOX_TITLE", "DialogBox title");
	define("DIALOGBOX_CONTENT", "DialogBox content");
	define("TEXT_ON_BODY", "Sample text on the page");
	define("LINK_ON_BODY", "Sample link on the page");
	define("BODY_TEXT_LINK_NOTE", "See bottom of page");
	define("WARNING_CHANGE_PLEASE_SAVE", "Warning, please save the form before change this field.");
	
	define("BTN_VALIDATE", "Validate");
	define("CONFIG_FILE", "Configuration");
	define("CONFIG_FILE_OK", "Your configuration has been saved !");
	define("CONFIG_FILE_NOT_OK", "Error during saving configuration file !");
?>
